'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.default = cli;

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _stream = require('stream');

var _yargs = require('yargs');

var _yargs2 = _interopRequireDefault(_yargs);

var _ = require('.');

var _2 = _interopRequireDefault(_);

var _commands = require('./commands');

var _commands2 = _interopRequireDefault(_commands);

var _package = require('../package.json');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function cli(printer) {
    var args = _yargs2.default.env('EZS').usage('Usage: $0 [options] [<file>]').version(_package.version).options({
        verbose: {
            alias: 'v',
            default: false,
            describe: 'Print some informations',
            type: 'boolean'
        },
        daemon: {
            alias: 'd',
            default: false,
            describe: 'Launch daemon',
            type: 'boolean'
        },
        server: {
            alias: 's',
            describe: 'Server to dispach commands',
            type: 'string'
        },
        port: {
            alias: 'p',
            describe: 'Change daemon\'port',
            default: 31976,
            type: 'number'
        },
        env: {
            alias: 'e',
            default: false,
            describe: 'Execute commands with environement variables as input',
            type: 'boolean'
        }
    }).epilogue('for more information, find our manual at https://github.com/touv/node-ezs');

    var argv = args.argv;
    var firstarg = argv._.shift();

    if (argv.daemon) {
        _2.default.createCluster();
        if (!argv.server) {
            argv.server = '127.0.0.1';
        }
    }

    if (!argv.daemon && !firstarg) {
        _yargs2.default.showHelp();
        process.exit(1);
    }

    if (firstarg) {
        var file = void 0;
        try {
            file = _fs2.default.realpathSync(firstarg);
        } catch (e) {
            printer.error(firstarg + ' doesn\'t exists.');
            _yargs2.default.showHelp();
            process.exit(1);
        }

        if (!_fs2.default.statSync(file).isFile()) {
            printer.error(firstarg + ' isn\'t a file.');
            _yargs2.default.showHelp();
            process.exit(1);
        }

        var script = _fs2.default.readFileSync(file).toString();
        var cmds = new _commands2.default(_2.default.parseString(script));

        var input = argv.env ? new _stream.PassThrough({ objectMode: true }) : process.stdin;

        if (argv.env) {
            // Use Env vars as INPUT
            if (argv.verbose) {
                printer.error('Reading environement variables...');
            }
            input.write(process.env);
            input.end();
        } else {
            // Use STDIN as INPUT
            if (argv.verbose) {
                printer.error('Reading standard input...');
            }
            input.resume();
            input.setEncoding('utf8');
        }

        var servers = Array.isArray(argv.server) ? argv.server : [argv.server];
        var stream1 = void 0;
        if (argv.server) {
            var runplan = cmds.analyse();
            stream1 = runplan.reduce(function (stream, section) {
                if (section.func === 'pipeline') {
                    return stream.pipe(_2.default.pipeline(section.cmds));
                }
                return stream.pipe(_2.default.dispatch(section.cmds, servers));
            }, input);
        } else {
            stream1 = input.pipe(_2.default.pipeline(cmds.get()));
        }
        var stream2 = stream1.pipe(_2.default.toBuffer());
        stream2.on('end', function () {
            process.exit(1);
        });
        stream2.pipe(process.stdout);
    }
}