'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _stream = require('stream');

var _assert = require('assert');

var _assert2 = _interopRequireDefault(_assert);

var _http = require('http');

var _http2 = _interopRequireDefault(_http);

var _pMap = require('p-map');

var _pMap2 = _interopRequireDefault(_pMap);

var _mergeStream = require('merge-stream');

var _mergeStream2 = _interopRequireDefault(_mergeStream);

var _parameter = require('./parameter');

var _parameter2 = _interopRequireDefault(_parameter);

var _config = require('./config');

var _config2 = _interopRequireDefault(_config);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var parseAddress = function parseAddress(srvr) {
    if (typeof srvr !== 'string') {
        return null;
    }
    var hostWithPort = srvr.match(/^\[?([^\]]+)\]?:(\d+)$/);
    if (hostWithPort) {
        return {
            hostname: hostWithPort[1],
            port: Number(hostWithPort[2])
        };
    }
    return {
        hostname: srvr,
        port: Number(_config2.default.port)
    };
};

var registerTo = function registerTo(_ref, commands) {
    var hostname = _ref.hostname,
        port = _ref.port;
    return new Promise(function (resolve, reject) {
        var requestBody = JSON.stringify(commands);
        var requestOptions = {
            hostname: hostname,
            port: port,
            path: '/',
            method: 'POST',
            headers: {
                'Content-Type': 'application/json',
                'Content-Length': requestBody.length,
                'X-Parameter': _parameter2.default.pack()
            }
        };
        var req = _http2.default.request(requestOptions, function (res) {
            var requestResponse = '';
            res.setEncoding('utf8');
            res.on('error', function (error) {
                reject(error);
            });
            res.on('data', function (chunk) {
                requestResponse += chunk;
            });
            res.on('end', function () {
                try {
                    var result = JSON.parse(requestResponse);
                    console.log('Register ' + hostname + ':' + port + ' with ' + result + '.');
                    resolve({
                        hostname: hostname,
                        port: port,
                        path: '/' + result,
                        method: 'POST',
                        headers: {
                            'Transfer-Encoding': 'chunked',
                            'Content-Type': ' application/json'
                        }
                    });
                } catch (e) {
                    reject(e);
                }
            });
        });
        req.on('error', function (e) {
            reject(e);
        });
        req.write(requestBody);
    });
};

var connectTo = function connectTo(ezs, serverOptions, funnel) {
    return new Promise(function (resolve, reject) {
        var handle = _http2.default.request(serverOptions, function (res) {
            if (res.statusCode === 200) {
                funnel.add(res);
            } else {
                funnel.emit('error', new Error(serverOptions.hostname + ':' + serverOptions.port + ' return ' + res.statusCode));
            }
        });
        handle.on('socket', function () {
            var input = new _stream.PassThrough({ objectMode: true });
            input.pipe(ezs('encoder')).pipe(handle);
            resolve(input);
        });
        handle.on('error', function (e) {
            reject(e);
        });
    });
};

var Dispatch = function (_Duplex) {
    _inherits(Dispatch, _Duplex);

    function Dispatch(ezs, commands, servers) {
        _classCallCheck(this, Dispatch);

        var _this = _possibleConstructorReturn(this, (Dispatch.__proto__ || Object.getPrototypeOf(Dispatch)).call(this, { objectMode: true }));

        _this.handles = [];

        _this.tubin = new _stream.PassThrough({ objectMode: true });
        _this.tubout = _this.tubin.pipe(ezs('decoder'));

        _this.on('finish', function () {
            _this.handles.forEach(function (handle) {
                return handle.end();
            });
        });
        _this.tubout.on('data', function (chunk, encoding) {
            _this.push(chunk, encoding);
        });
        _this.tubout.on('finish', function () {
            _this.push(null);
        });
        _this.tubout.on('error', function (e) {
            console.error('Unlikely error', e);
        });
        _this.tubout.pause();

        (0, _assert2.default)(Array.isArray(commands), 'commands should be an array.');
        (0, _assert2.default)(Array.isArray(servers), 'servers should be an array.');

        _this.servers = servers.map(parseAddress).filter(function (x) {
            return x;
        });
        _this.commands = commands;
        _this.semaphore = true;
        _this.lastIndex = 0;
        _this.funnel = (0, _mergeStream2.default)();
        _this.funnel.on('error', function (e) {
            _this.emit('error', e);
        });
        _this.funnel.pipe(_this.tubin);
        _this.ezs = ezs;
        return _this;
    }

    _createClass(Dispatch, [{
        key: '_write',
        value: function _write(chunk, encoding, callback) {
            var self = this;
            if (self.semaphore) {
                self.semaphore = false;
                (0, _pMap2.default)(self.servers, function (server) {
                    return registerTo(server, self.commands);
                }).then(function (workers) {
                    (0, _pMap2.default)(workers, function (worker) {
                        return connectTo(self.ezs, worker, self.funnel);
                    }).then(function (handles) {
                        self.handles = handles;
                        self.balance(chunk, encoding, callback);
                    }, callback);
                }, callback);
            } else {
                self.balance(chunk, encoding, callback);
            }
        }
    }, {
        key: '_read',
        value: function _read(size) {
            this.lastSize = size;
            if (this.tubout.isPaused()) {
                this.tubout.resume();
            }
        }
    }, {
        key: 'balance',
        value: function balance(chunk, encoding, callback) {
            this.lastIndex += 1;
            if (this.lastIndex >= this.handles.length) {
                this.lastIndex = 0;
            }
            this.handles[this.lastIndex].write(chunk, encoding, callback);
        }
    }]);

    return Dispatch;
}(_stream.Duplex);

exports.default = Dispatch;