'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _lodash = require('lodash');

var _lodash2 = _interopRequireDefault(_lodash);

var _util = require('util');

var _util2 = _interopRequireDefault(_util);

var _JSONStream = require('JSONStream');

var _JSONStream2 = _interopRequireDefault(_JSONStream);

var _json = require('./json');

var _json2 = _interopRequireDefault(_json);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function assign(data, feed) {
    if (this.isLast()) {
        return feed.send(data);
    }
    var test = this.getParam('test', true);
    if (!test) {
        return feed.send(data);
    }
    var params = this.getParams();

    // check if missing value
    if (Array.isArray(params.path) && !Array.isArray(params.value)) {
        params.value = [params.value];
    }
    var keys = this.getParam('path', []);
    var vals = this.getParam('value', []);

    if (Array.isArray(keys)) {
        var values = _lodash2.default.take(vals, keys.length);
        var assets = _lodash2.default.zipObject(keys, values);
        Object.keys(assets).forEach(function (key) {
            _lodash2.default.set(data, key, assets[key]);
        });
    } else {
        _lodash2.default.set(data, keys, vals);
    }
    return feed.send(data);
}

function replace(data, feed) {
    if (this.isLast()) {
        return feed.send(data);
    }
    var test = this.getParam('test', true);
    if (!test) {
        return feed.send(data);
    }
    var params = this.getParams();

    // check if missing value
    if (Array.isArray(params.path) && !Array.isArray(params.value)) {
        params.value = [params.value];
    }
    var keys = this.getParam('path', []);
    var vals = this.getParam('value', []);
    var obj = {};
    if (Array.isArray(keys)) {
        var values = _lodash2.default.take(vals, keys.length);
        var assets = _lodash2.default.zipObject(keys, values);
        Object.keys(assets).forEach(function (key) {
            _lodash2.default.set(obj, key, assets[key]);
        });
    } else {
        _lodash2.default.set(obj, keys, vals);
    }
    return feed.send(obj);
}

function debug(data, feed) {
    if (this.isLast()) {
        return feed.send(data);
    }
    var level = this.getParam('level', 'log');
    var text = this.getParam('text', 'valueOf');
    if (typeof console[level] === 'function') {
        var logOpts = { showHidden: false, depth: 3, colors: true };
        var logFunc = console[level];
        logFunc(text.concat('#').concat(this.getIndex()).concat(' ->'), _util2.default.inspect(data, logOpts));
    }
    return feed.send(data);
}

function transit(data, feed) {
    return feed.send(data);
}

function shift(data, feed) {
    feed.write(data);
    feed.close();
}

function extract(data, feed) {
    if (this.isLast()) {
        return feed.send(data);
    }
    var keys = this.getParam('path', []);
    if (!Array.isArray(keys)) {
        keys = [keys];
    }

    keys = keys.filter(function (k) {
        return typeof k === 'string';
    });
    var values = keys.map(function (key) {
        return _lodash2.default.get(data, key);
    }).filter(function (val) {
        return val;
    });

    if (values.length === 0) {
        return feed.send(new Error('Nonexistent path.'));
    } else if (values.length === 1) {
        return feed.send(values[0]);
    }
    return feed.send(values);
}

function keep(data, feed) {
    if (this.isLast()) {
        return feed.send(data);
    }
    var keys = this.getParam('path', []);
    if (!Array.isArray(keys)) {
        keys = [keys];
    }
    var obj = {};
    keys.filter(function (k) {
        return typeof k === 'string';
    }).forEach(function (key) {
        return _lodash2.default.set(obj, key, _lodash2.default.get(data, key));
    });
    return feed.send(obj);
}

function concat(data, feed) {
    if (this.buffer === undefined) {
        this.buffer = '';
    }
    if (this.isLast()) {
        feed.send(this.buffer);
        return feed.close();
    }
    this.buffer = this.buffer.concat(data);
    return feed.end();
}

function json(data, feed) {
    if (this.isLast()) {
        return feed.send(data);
    }
    return feed.send(JSON.parse(data));
}

function jsonezs(data, feed) {
    if (this.isLast()) {
        return feed.send(data);
    }
    return feed.send(_json2.default.parse(data));
}

function encoder(data, feed) {
    var output = '';
    if (this.isFirst()) {
        output = '[';
    } else {
        output = ',';
    }
    if (!this.isLast()) {
        feed.write(output.concat(JSON.stringify(data, null, null)));
    } else if (this.isLast() && this.getIndex() > 0) {
        feed.write(']');
        feed.close();
    } else {
        feed.write('[]');
        feed.close();
    }
    feed.end();
}

function decoder(data, feed) {
    if (!this.handle) {
        var separator = this.getParam('separator', '*');
        this.handle = _JSONStream2.default.parse(separator);
        this.handle.on('data', function (obj) {
            return feed.write(obj);
        });
    }
    if (!this.isLast()) {
        if (!this.handle.write(data)) {
            this.handle.once('drain', function () {
                return feed.end();
            });
        } else {
            process.nextTick(function () {
                return feed.end();
            });
        }
    } else {
        this.handle.end();
        process.nextTick(function () {
            feed.close();
        });
    }
}

exports.default = {
    extract: extract,
    assign: assign,
    replace: replace,
    shift: shift,
    keep: keep,
    debug: debug,
    concat: concat,
    json: json,
    jsonezs: jsonezs,
    encoder: encoder,
    decoder: decoder,
    transit: transit
};