'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; };

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var pluginsList = {};

function resolve(name) {
    try {
        return require.resolve(name);
    } catch (e) {
        return null;
    }
}

function all() {
    return Object.keys(pluginsList);
}

function get(ezs, plugin, opts) {
    if (plugin === 'use') {
        // very special case : to load statement in the current pipeline
        var args = !Array.isArray(opts) ? [opts] : opts;
        args.forEach(function (arg) {
            if (arg.plugin) {
                var names = arg.plugin.get();
                if (!Array.isArray(names)) {
                    names = [names];
                }
                names.forEach(function (name) {
                    var plugName1 = resolve('ezs-'.concat(name.replace(/^ezs-/, '')));
                    var plugName2 = ezs.getPath().map(function (dir) {
                        return _path2.default.resolve(dir, name);
                    }).map(function (fil) {
                        return resolve(fil);
                    }).filter(function (fun) {
                        return fun !== null;
                    }).shift();
                    var plugName3 = resolve(name);
                    if (plugName1) {
                        // eslint-disable-next-line
                        ezs.use(require(plugName1));
                    } else if (plugName2) {
                        // eslint-disable-next-line
                        ezs.use(require(plugName2));
                    } else if (plugName3) {
                        // eslint-disable-next-line
                        ezs.use(require(plugName3));
                    } else {
                        throw new Error('\'' + name + '\' is not loaded. It was not found (try to install it).');
                    }
                });
            }
        });
        return function (data, feed) {
            return feed.send(data);
        };
    } else if (typeof plugin === 'function') {
        return plugin;
    } else if (typeof plugin === 'string' && pluginsList[plugin]) {
        return pluginsList[plugin];
    } else if ((typeof plugin === 'undefined' ? 'undefined' : _typeof(plugin)) === 'object') {
        var firstKey = Object.keys(plugin).slice(0, 1);
        if (typeof plugin[firstKey] === 'function') {
            return plugin[firstKey];
        }
    }
    throw new Error('\'' + plugin + '\' is not loaded. It\'s not a valid statement function.');
}

function set(ezs, plugin) {
    if ((typeof plugin === 'undefined' ? 'undefined' : _typeof(plugin)) !== 'object') {
        throw new Error("Statement is not loaded. It's not a valid plugin (should be an object).");
    }
    var pluginList = plugin.default ? plugin.default : plugin; // ES6 hack
    Object.keys(pluginList).forEach(function (pluginName) {
        if (typeof pluginList[pluginName] === 'function') {
            pluginsList[pluginName] = pluginList[pluginName];
        } else if (_typeof(pluginList[pluginName]) === 'object') {
            ezs.use(pluginList[pluginName]);
        } else {
            throw new Error(pluginName + ' is not loaded. It\'s not a valid plugin.');
        }
    });
    return ezs;
}

function exists(ezs, pluginName) {
    return pluginsList[pluginName] !== undefined;
}

exports.default = {
    get: get,
    set: set,
    all: all,
    exists: exists
};