# tmp-filepath [![NPM version](https://img.shields.io/npm/v/tmp-filepath.svg?style=flat)](https://www.npmjs.com/package/tmp-filepath) [![NPM monthly downloads](https://img.shields.io/npm/dm/tmp-filepath.svg?style=flat)](https://npmjs.org/package/tmp-filepath) [![npm total downloads][downloads-img]][downloads-url]

> Generate temporary filepath string (without writing to disk). Using scaleable, secure and fast cross-platform [cuid][] package

[![code climate][codeclimate-img]][codeclimate-url] 
[![standard code style][standard-img]][standard-url] 
[![linux build status][travis-img]][travis-url] 
[![windows build status][appveyor-img]][appveyor-url] 
[![coverage status][coveralls-img]][coveralls-url] 
[![dependency status][david-img]][david-url]

You might also be interested in [always-done](https://github.com/hybridables/always-done#readme).

## Table of Contents
- [Install](#install)
- [Usage](#usage)
- [API](#api)
  * [tmpFilepath](#tmpfilepath)
- [Related](#related)
- [Contributing](#contributing)
- [Building docs](#building-docs)
- [Running tests](#running-tests)
- [Author](#author)
- [License](#license)

_(TOC generated by [verb](https://github.com/verbose/verb) using [markdown-toc](https://github.com/jonschlinkert/markdown-toc))_

## Install
Install with [npm](https://www.npmjs.com/)

```
$ npm install tmp-filepath --save
```

or install using [yarn](https://yarnpkg.com)

```
$ yarn add tmp-filepath
```

## Usage
> For more use-cases see the [tests](test.js)

```js
const tmpFilepath = require('tmp-filepath')
```

## API

### [tmpFilepath](index.js#L35)
> Generate temporary filepath string.

**Params**

* `[ext]` **{String}**: extension to be appended to generated filepath    
* `returns` **{String}**: generated filepath  

**Example**

```js
const tmpFilepath = require('tmp-filepath')

console.log(tmpFilepath())
// => /tmp/cia0ervrm0000vppvw0t61v9m

console.log(tmpFilepath('.js'))
// => /tmp/cia0ervrm0000vppvw0t61v9m.js
```

## Related
- [always-done](https://www.npmjs.com/package/always-done): Handle completion and errors with elegance! Support for streams, callbacks, promises, child processes, async/await and sync functions. A drop-in replacement… [more](https://github.com/hybridables/always-done#readme) | [homepage](https://github.com/hybridables/always-done#readme "Handle completion and errors with elegance! Support for streams, callbacks, promises, child processes, async/await and sync functions. A drop-in replacement for [async-done][] - pass 100% of its tests plus more")
- [each-promise](https://www.npmjs.com/package/each-promise): Iterate over promises, promise-returning or async/await functions in series or parallel. Support settle (fail-fast), concurrency (limiting) and hooks system (start… [more](https://github.com/tunnckocore/each-promise#readme) | [homepage](https://github.com/tunnckocore/each-promise#readme "Iterate over promises, promise-returning or async/await functions in series or parallel. Support settle (fail-fast), concurrency (limiting) and hooks system (start, beforeEach, afterEach, finish)")
- [minibase](https://www.npmjs.com/package/minibase): Minimalist alternative for Base. Build complex APIs with small units called plugins. Works well with most of the already existing… [more](https://github.com/node-minibase/minibase#readme) | [homepage](https://github.com/node-minibase/minibase#readme "Minimalist alternative for Base. Build complex APIs with small units called plugins. Works well with most of the already existing [base][] plugins.")
- [mukla](https://www.npmjs.com/package/mukla): Small, parallel and fast test framework with suppport for async/await, promises, callbacks, streams and observables. Targets and works at node.js… [more](https://github.com/tunnckocore/mukla#readme) | [homepage](https://github.com/tunnckocore/mukla#readme "Small, parallel and fast test framework with suppport for async/await, promises, callbacks, streams and observables. Targets and works at node.js v0.10 and above.")
- [rolldown](https://www.npmjs.com/package/rolldown): Modern bundler built on [rollup][] with support for presets and better configuration experience | [homepage](https://github.com/rolldown/rolldown#readme "Modern bundler built on [rollup][] with support for presets and better configuration experience")
- [rollup](https://www.npmjs.com/package/rollup): Next-generation ES6 module bundler | [homepage](https://github.com/rollup/rollup "Next-generation ES6 module bundler")
- [tempfile](https://www.npmjs.com/package/tempfile): Get a random temp file path | [homepage](https://github.com/sindresorhus/tempfile#readme "Get a random temp file path")
- [tmp-file](https://www.npmjs.com/package/tmp-file): Create actual and temporary file on disk - support stream, sync, gulp, vinyl and async. Returns partially Record/Vinyl File Object | [homepage](https://github.com/tunnckocore/tmp-file#readme "Create actual and temporary file on disk - support stream, sync, gulp, vinyl and async. Returns partially Record/Vinyl File Object")
- [try-catch-core](https://www.npmjs.com/package/try-catch-core): Low-level package to handle completion and errors of sync or asynchronous functions, using [once][] and [dezalgo][] libs. Useful for and… [more](https://github.com/hybridables/try-catch-core#readme) | [homepage](https://github.com/hybridables/try-catch-core#readme "Low-level package to handle completion and errors of sync or asynchronous functions, using [once][] and [dezalgo][] libs. Useful for and used in higher-level libs such as [always-done][] to handle completion of anything.")

## Contributing
Pull requests and stars are always welcome. For bugs and feature requests, [please create an issue](https://github.com/tunnckoCore/tmp-filepath/issues/new).  
Please read the [contributing guidelines](CONTRIBUTING.md) for advice on opening issues, pull requests, and coding standards.  
If you need some help and can spent some cash, feel free to [contact me at CodeMentor.io](https://www.codementor.io/tunnckocore?utm_source=github&utm_medium=button&utm_term=tunnckocore&utm_campaign=github) too.

**In short:** If you want to contribute to that project, please follow these things

1. Please DO NOT edit [README.md](README.md), [CHANGELOG.md](CHANGELOG.md) and [.verb.md](.verb.md) files. See ["Building docs"](#building-docs) section.
2. Ensure anything is okey by installing the dependencies and run the tests. See ["Running tests"](#running-tests) section.
3. Always use `npm run commit` to commit changes instead of `git commit`, because it is interactive and user-friendly. It uses [commitizen][] behind the scenes, which follows Conventional Changelog idealogy.
4. Do NOT bump the version in package.json. For that we use `npm run release`, which is [standard-version][] and follows Conventional Changelog idealogy.

Thanks a lot! :)

## Building docs
Documentation and that readme is generated using [verb-generate-readme][], which is a [verb][] generator, so you need to install both of them and then run `verb` command like that

```
$ npm install verbose/verb#dev verb-generate-readme --global && verb
```

_Please don't edit the README directly. Any changes to the readme must be made in [.verb.md](.verb.md)._

## Running tests
Clone repository and run the following in that cloned directory

```
$ npm install && npm test
```

## Author
**Charlike Mike Reagent**

+ [github/tunnckoCore](https://github.com/tunnckoCore)
+ [twitter/tunnckoCore](http://twitter.com/tunnckoCore)
+ [codementor/tunnckoCore](https://codementor.io/tunnckoCore)

## License
Copyright © 2016-2017, [Charlike Mike Reagent](http://i.am.charlike.online). Released under the [MIT license](LICENSE).

***

_This file was generated by [verb-generate-readme](https://github.com/verbose/verb-generate-readme), v0.2.3, on January 03, 2017._  
_Project scaffolded using [charlike][] cli._

[always-done]: https://github.com/hybridables/always-done
[async-done]: https://github.com/gulpjs/async-done
[base]: https://github.com/node-base/base
[charlike]: https://github.com/tunnckocore/charlike
[commitizen]: https://github.com/commitizen/cz-cli
[cuid]: https://github.com/ericelliott/cuid
[dezalgo]: https://github.com/npm/dezalgo
[once]: https://github.com/isaacs/once
[standard-version]: https://github.com/conventional-changelog/standard-version
[verb-generate-readme]: https://github.com/verbose/verb-generate-readme
[verb]: https://github.com/verbose/verb

[downloads-url]: https://www.npmjs.com/package/tmp-filepath
[downloads-img]: https://img.shields.io/npm/dt/tmp-filepath.svg

[codeclimate-url]: https://codeclimate.com/github/tunnckoCore/tmp-filepath
[codeclimate-img]: https://img.shields.io/codeclimate/github/tunnckoCore/tmp-filepath.svg

[travis-url]: https://travis-ci.org/tunnckoCore/tmp-filepath
[travis-img]: https://img.shields.io/travis/tunnckoCore/tmp-filepath/master.svg?label=linux

[appveyor-url]: https://ci.appveyor.com/project/tunnckoCore/tmp-filepath
[appveyor-img]: https://img.shields.io/appveyor/ci/tunnckoCore/tmp-filepath/master.svg?label=windows

[coveralls-url]: https://coveralls.io/r/tunnckoCore/tmp-filepath
[coveralls-img]: https://img.shields.io/coveralls/tunnckoCore/tmp-filepath.svg

[david-url]: https://david-dm.org/tunnckoCore/tmp-filepath
[david-img]: https://img.shields.io/david/tunnckoCore/tmp-filepath.svg

[standard-url]: https://github.com/feross/standard
[standard-img]: https://img.shields.io/badge/code%20style-standard-brightgreen.svg

[rollup]: https://github.com/rollup/rollup